@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2006  NTT DATA CORPORATION
  *
- * Version: 1.0.2 2006/02/13
+ * Version: 1.1.1   2006/05/15
  *
  */
 #include <stdio.h>
@@ -274,10 +274,6 @@ static int AddFileACL(const char *filename, WORD perm, const int index) {
 		fprintf(stderr, "%s: ERROR: domain is out of range.\n", __FUNCTION__);
 		return -EINVAL;
 	}
-	if (!IsCorrectPath(filename, 1)) {
-		fprintf(stderr, "%s: Invalid pathname '%s'\n",  __FUNCTION__, filename);
-		return -EINVAL;
-	}
 	if (perm > 7 || !perm) {
 		fprintf(stderr, "%s: Invalid permission '%d %s'\n",  __FUNCTION__, perm, filename);
 		return -EINVAL;
@@ -1495,7 +1491,7 @@ static void ACLListLoop(void) {
 				memset(buffer, 0, sizeof(buffer));
 				getnstr(buffer, sizeof(buffer) - 1); noecho();
 				NormalizeLine(buffer);
-				if (sscanf(buffer, "%d", &perm) == 1 && (cp = strchr(buffer, ' ')) != NULL && IsCorrectPath(cp + 1, 1)) {
+				if (sscanf(buffer, "%d", &perm) == 1 && (cp = strchr(buffer, ' ')) != NULL) {
 					if (AddFileACL(cp + 1, (WORD) perm, domain) == 0) domain_acl_updated = 1;
 				} else if (strncmp(buffer, "allow_", 6) == 0) {
 					if (AddStringEntry(buffer, domain) == 0) domain_acl_updated = 1;
